***********
Basic Usage
***********

Installation
============
Install ``freezerbox`` using ``pip``::

    $ pip install freezerbox

- Requires python≥3.6
- Uses `semantic versioning`_.

.. _`semantic versioning`: https://semver.org/
